@@ -1,7 +1,7 @@
 package Log::ger;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $DATE = '2017-07-12'; # DATE
+our $VERSION = '0.015'; # VERSION
 
 #IFUNBUILT
 # # use strict;
@@ -157,7 +157,7 @@ sub run_hooks {
         unshift @hooks, @{ $Per_Hash_Hooks{$addr}{$phase} || [] };
     } elsif ($target eq 'object') {
         my ($addr) = "$target_arg" =~ $re_addr;
-        unshift @hooks, @{ $Per_Object_Hooks{$target_arg}{$phase} || [] };
+        unshift @hooks, @{ $Per_Object_Hooks{$addr}{$phase} || [] };
     }
 
     my $res;
@@ -482,7 +482,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
